@@ -9,14 +9,14 @@ if __name__ == '__main__':
     # Vectioneer camera
     endpoint_1 = "ws://motorcortex:5558:5557"
     req, sub = motorcortex.connect(endpoint_1, motorcortex_types, parameter_tree,
-                                   certificate="mcx.cert.pem", timeout_ms=1000,
+                                   certificate="mcx.cert.crt", timeout_ms=1000,
                                    login="", password="")
 
 
     # Local processing
     endpoint_2 = "wss://localhost:5568:5567"
     req1, sub1 = motorcortex.connect(endpoint_2, motorcortex.MessageTypes(), motorcortex.ParameterTree(),
-                                   certificate="mcx.cert.pem", timeout_ms=1000,
+                                   certificate="mcx.cert.crt", timeout_ms=1000,
                                    login="", password="")
 
     print("Sending data from {} to {}".format(endpoint_1, endpoint_2))
