@@ -30,7 +30,7 @@ def main(id):
 
     # Open request connection
     req, sub = motorcortex.connect("wss://192.168.2.100:5568:5567", motorcortex_types, parameter_tree,
-                                   certificate="mcx.cert.pem", timeout_ms=1000,
+                                   certificate="mcx.cert.crt", timeout_ms=1000,
                                    login="", password="")
 
     start = time.time()
